#
# spec file for package ghc-formatting
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name formatting
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        7.1.3
Release:        bp155.3.13
Summary:        Combinator-based type-safe formatting (like printf() or FORMAT)
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/2.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-clock-devel
BuildRequires:  ghc-double-conversion-devel
BuildRequires:  ghc-old-locale-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-hspec-devel
%endif

%description
Combinator-based type-safe formatting (like printf() or FORMAT), modelled from
the HoleyMonoids package.

See the README at <https://github.com/AJChapman/formatting#readme> for more
info.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Wed Feb  2 2022 Peter Simons <psimons@suse.com>
- Update formatting to version 7.1.3 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Jul  1 2021 psimons@suse.com
- Update formatting to version 7.1.3.
  7.1.3
  * Fix the GHCJS build by not using `double-conversion`, as it relies on a native C library which obviously isn't available in GHCJS (it is still used in native builds).
* Mon Apr  5 2021 psimons@suse.com
- Update formatting to version 7.1.2.
  7.1.2
  * Removed direct dependency on integer-gmp, instead using very similar code from the `text` package. This changed the implementation of `build` for `Integer`, which results in better performance in some cases, and no performance degradation. See the benchmarking reports in bench/reports for more details.
  * formatting now compiles on GHCJS (due to the change above).
  * Added some benchmarking, starting based on code from the `string-interpolate` package.
  * Added INLINE pragmas to many very short functions. Results in better performance in the benchmarks.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Fri Oct 16 2020 psimons@suse.com
- Add formatting at version 7.1.1.
